pub trait IdentifyAccount {
type AccountId;
// Required method
fn into_account(self) -> Self::AccountId;
}Expand description
Some type that is able to be collapsed into an account ID. It is not possible to recreate the original value from the account ID.
Required Associated Types
Required Methods
Sourcefn into_account(self) -> Self::AccountId
fn into_account(self) -> Self::AccountId
Transform into an account.
Implementations on Foreign Types
Sourceimpl IdentifyAccount for Public
impl IdentifyAccount for Public
Sourceimpl IdentifyAccount for Public
impl IdentifyAccount for Public
Sourceimpl IdentifyAccount for Public
Available on crate feature bls-experimental only.
impl IdentifyAccount for Public
Available on crate feature
bls-experimental only.